@@ -806,11 +806,13 @@ static void	decifer_mode (const char *modes, Channel *chan)
 			break;
 		case 5:
 			if (!add) break;
+			FALLTHROUGH
 		case 4: case 3: case 2:
 			if ((arg = next_arg(rest, &rest)))
 				break;
 			yell("WARNING:  Mode parser or server is BROKE.  Mode=%c%c args: %s",
 					add ? '+' : '-', *mode_str, rest);
+			FALLTHROUGH
 		default:
 			yell("Defaulting %c%c to CHANMODE type D", add?'+':'-', *mode_str);
 	    }
@@ -1671,7 +1673,7 @@ void	channel_check_windows (void)
 			continue;			/* This is OK. */
 
 		if (tmp->server != get_window_server(tmp->winref))
-		    if (get_server_status(tmp->server) != SERVER_CLOSING)
+		    if (get_server_state(tmp->server) != SERVER_CLOSING)
 			panic(0, "Referential integrity failure: "
 			      "Channel [%s] on server [%d] is connected "
 			      "to window [%d] on server [%d]",
@@ -1687,7 +1689,7 @@ void	channel_check_windows (void)
 			panic(1, "I thought we just checked for this! [2]");
 
 		if (!get_window_by_refnum(tmp->winref))
-		    if (get_server_status(tmp->server) != SERVER_CLOSING)
+		    if (get_server_state(tmp->server) != SERVER_CLOSING)
 			panic(0, "Referential integrity failure: "
 			      "Channel [%s] on server [%d] is connected "
 			      "to window [%d] "
